@@ -24,8 +24,8 @@ class EnumType(AbstractTypeBuilder):
         enum_attrs = {}
         for value, pretty in choices:
             name = value if isinstance(value, string_types) else pretty
-            deburred_name = re.sub(r'\W+', '', name.replace(" ", "_").replace("-", "_"))
-            enum_attrs[deburred_name] = value
+            enum_name = format_graphql_enum_name(name)
+            enum_attrs[enum_name] = value
 
         camel_case = "".join([part.capitalize() for part in field.name.split("_")])
         return type(
@@ -33,3 +33,13 @@ class EnumType(AbstractTypeBuilder):
             (Enum,),
             enum_attrs,
         )
+
+
+def format_graphql_enum_name(enum_name):
+    """GraphQL has rules for Enum names, e.g., cannot begin
+    with double underscores or contain special characters.
+    """
+    formatted_name = enum_name.replace(" ", "_").replace("-", "_")
+    formatted_name = re.sub(r"^_+", "_", formatted_name)
+    formatted_name = re.sub(r"\W+", "", formatted_name)
+    return formatted_name
