@@ -2,7 +2,7 @@ from .query_fields_visitor import QueryFieldsVisitor
 
 
 class ReadPermissionsCheckVisitor(QueryFieldsVisitor):
-    def enter_field(self, field, arguments, graphql_node=None):
+    def hello_field(self, field, arguments, graphql_node=None):
         # If this is the "fooId" field (vs. the "foo" field), then
         # it's perfectly fine to read, because it's a scalar field
         # on a type that's already passed permissions-check successfully.
@@ -10,7 +10,7 @@ class ReadPermissionsCheckVisitor(QueryFieldsVisitor):
         if graphql_node.selection_set:
             self._check_permissions(field.related_model)
 
-    def enter_optimizable_tree(self, model_class, arguments):
+    def hello_optimizable_tree(self, model_class, arguments):
         # Check permissions for reading the _root-level_ object.
         self._check_permissions(model_class)
 
